/** Double-include prevention */
#if defined _togplaytimerecords_included_
  #endinput
#endif
#define _togplaytimerecords_included_
 
/**
 * Return minutes logged for client under global play time.
 *
 * @param	client		Client index
 * @return				Integer number of minutes logged for client under global play time, -1 if player hasnt loaded, or -2 if invalid client.
 */
native tpr_GlobalPlayTime(client);

/**
 * Return minutes logged for client under global spec time.
 *
 * @param	client		Client index
 * @return				Integer number of minutes logged for client under global spec time, -1 if player hasnt loaded, or -2 if invalid client.
 */
native tpr_GlobalSpecTime(client);

/**
 * Return minutes logged for client under server play time.
 *
 * @param	client		Client index
 * @return				Integer number of minutes logged for client under server play time, -1 if player hasnt loaded, or -2 if invalid client.
 */
native tpr_ServerPlayTime(client);

/**
 * Return minutes logged for client under server spec time.
 *
 * @param	client		Client index
 * @return				Integer number of minutes logged for client under server spec time, -1 if player hasnt loaded, or -2 if invalid client.
 */
native tpr_ServerSpecTime(client);

/**
 * Return minutes saved in plugin for client under server play time for current session.
 *
 * @param	client		Client index
 * @return				Integer number of minutes logged for client under server play time for current session, -1 if player hasnt loaded, or -2 if invalid client.
 */
native tpr_CurrentPlayTime(client);

/**
 * Return minutes saved in plugin for client under server spec time for current session.
 *
 * @param	client		Client index
 * @return				Integer number of minutes logged for client under server spec time for current session, -1 if player hasnt loaded, or -2 if invalid client.
 */
native tpr_CurrentSpecTime(client);

/**
 * Return relative rank for global play time of client.
 *
 * @param	client		Client index
 * @return				Integer rank of client, 0 if player is unranked, -1 if player hasnt loaded, -2 if invalid client, or -3 if ranks are disabled.
 */
native tpr_GlobalPlayRank(client);

/**
 * Return relative rank for global spec time of client.
 *
 * @param	client		Client index
 * @return				Integer rank of client, 0 if player is unranked, -1 if player hasnt loaded, -2 if invalid client, or -3 if ranks are disabled.
 */
native tpr_GlobalSpecRank(client);

/**
 * Return relative rank for server play time of client.
 *
 * @param	client		Client index
 * @return				Integer rank of client, 0 if player is unranked, -1 if player hasnt loaded, -2 if invalid client, or -3 if ranks are disabled.
 */
native tpr_ServerPlayRank(client);

/**
 * Return relative rank for server spec time of client.
 *
 * @param	client		Client index
 * @return				Integer rank of client, 0 if player is unranked, -1 if player hasnt loaded, -2 if invalid client, or -3 if ranks are disabled.
 */
native tpr_ServerSpecRank(client);

/**
 * Return is player has loaded from the database or not
 *
 * @param	client		Client index
 * @return				2 if fully loaded (times and ranks), 1 if times only loaded, 0 if player hasnt loaded, or -1 if invalid client.
 */
native tpr_IsLoaded(client);

/* 
 * Called when a client finishes loading all ranks (times are already loaded at this point).
 * 
 * @return	None.
 */ 
forward TPRClientRanksLoaded(client);

/* 
 * Called when a client finishes loading all times.
 * 
 * @return	None.
 */ 
forward TPRClientTimesLoaded(client);

/* 
 * Called when a client is disconnecting.
 * 
 * @return	None.
 */ 
forward TPRClientDisconnecting(client, String:sSteamID[], iPlayTime, iSpecTime);

public SharedPlugin:__pl_togplaytimerecords =
{
	name = "togplaytimerecords",
	file = "togplaytimerecords.smx",
#if defined REQUIRE_PLUGIN
	required = 1
#else
	required = 0
#endif
};

#if !defined REQUIRE_PLUGIN
public __pl_togplaytimerecords_SetNTVOptional()
{
	MarkNativeAsOptional("tpr_GlobalPlayTime");
	MarkNativeAsOptional("tpr_GlobalSpecTime");
	MarkNativeAsOptional("tpr_ServerPlayTime");
	MarkNativeAsOptional("tpr_ServerSpecTime");
	MarkNativeAsOptional("tpr_CurrentPlayTime");
	MarkNativeAsOptional("tpr_CurrentSpecTime");
	MarkNativeAsOptional("tpr_GlobalPlayRank");
	MarkNativeAsOptional("tpr_GlobalSpecRank");
	MarkNativeAsOptional("tpr_ServerPlayRank");
	MarkNativeAsOptional("tpr_ServerSpecRank");
	MarkNativeAsOptional("tpr_IsLoaded");
}
#endif